@@ -1569,6 +1569,53 @@ describe('node-fetch', () => {
 		});
 	});
 
+	it('should not forward secure headers to 3th party', () => {
+		return fetch(`${base}redirect-to/302/https://httpbin.org/get`, {
+			headers: new Headers({
+				cookie: 'gets=removed',
+				cookie2: 'gets=removed',
+				authorization: 'gets=removed',
+				'www-authenticate': 'gets=removed',
+				'other-safe-headers': 'stays',
+				'x-foo': 'bar'
+			})
+		}).then(res => res.json()).then(json => {
+			const headers = new Headers(json.headers);
+			// Safe headers are not removed
+			expect(headers.get('other-safe-headers')).to.equal('stays');
+			expect(headers.get('x-foo')).to.equal('bar');
+			// Unsafe headers should not have been sent to httpbin
+			expect(headers.get('cookie')).to.equal(null);
+			expect(headers.get('cookie2')).to.equal(null);
+			expect(headers.get('www-authenticate')).to.equal(null);
+			expect(headers.get('authorization')).to.equal(null);
+		});
+	});
+
+	it('should forward secure headers to same host', () => {
+		return fetch(`${base}redirect-to/302/${base}inspect`, {
+			headers: new Headers({
+				cookie: 'is=cookie',
+				cookie2: 'is=cookie2',
+				authorization: 'is=authorization',
+				'other-safe-headers': 'stays',
+				'www-authenticate': 'is=www-authenticate',
+				'x-foo': 'bar'
+			})
+		}).then(res => res.json().then(json => {
+			const headers = new Headers(json.headers);
+			// Safe headers are not removed
+			expect(res.url).to.equal(`${base}inspect`);
+			expect(headers.get('other-safe-headers')).to.equal('stays');
+			expect(headers.get('x-foo')).to.equal('bar');
+			// Unsafe headers should not have been sent to httpbin
+			expect(headers.get('cookie')).to.equal('is=cookie');
+			expect(headers.get('cookie2')).to.equal('is=cookie2');
+			expect(headers.get('www-authenticate')).to.equal('is=www-authenticate');
+			expect(headers.get('authorization')).to.equal('is=authorization');
+		}));
+	});
+
 	it('should allow PATCH request', function() {
 		const url = `${base}inspect`;
 		const opts = {
@@ -2845,3 +2892,41 @@ describe('external encoding', () => {
 		});
 	});
 });
+
+describe('issue #1290', function() {
+
+	it('should keep query params', function() {
+		return fetch(`${base}inspect?month=2021-09`)
+		  .then(res => res.json())
+			.then(json => {
+				expect(json.url).to.equal('/inspect?month=2021-09')
+			})
+	})
+
+	it('should handle escaped unicode in URLs', () => {
+		const url = `${base}issues/1290/%E3%81%B2%E3%82%89%E3%81%8C%E3%81%AA`;
+		return fetch(url).then((res) => {
+			expect(res.status).to.equal(200);
+			return res.text().then(result => {
+				expect(result).to.equal('Success');
+			});
+		});
+	});
+
+	it('should handle unicode in URLs', () => {
+		const url = `${base}issues/1290/ひらがな`;
+		return fetch(url).then((res) => {
+			expect(res.status).to.equal(200);
+			return res.text().then(result => {
+				expect(result).to.equal('Success');
+			});
+		});
+	});
+
+	// #1342
+	it('should not throw with a valid URL', () => {
+		const url = 'https://r2---sn-n4v7sney.example.com';
+		new Request(url);
+	});
+
+});
